@@ -2,7 +2,7 @@
  *	Copyright 1996, University Corporation for Atmospheric Research
  *	See netcdf/COPYRIGHT file for copying and redistribution conditions.
  */
-/* "$Id: ncx.h,v 1.52 1997/06/04 22:27:12 davis Exp $" */
+/* "$Id: ncx.h,v 1.53 2000/04/05 19:36:56 steve Exp $" */
 
 #ifndef _NCX_H_
 #define _NCX_H_
@@ -45,6 +45,9 @@
 #ifndef NC_ERANGE
 #define NC_ERANGE (-60) /* N.B. must match value in netcdf.h */
 #endif
+#ifndef NC_ENOMEM
+#define NC_ENOMEM (-61) /* N.B. must match value in netcdf.h */
+#endif
 
 
 /*
