@@ -3,7 +3,7 @@
  *	See netcdf/COPYRIGHT file for copying and redistribution conditions.
  * 	
  */
-/* $Id: ncx_cray.c,v 1.56 1998/03/06 01:32:58 davis Exp $ */
+/* $Id: ncx_cray.c,v 1.58 2000/04/05 19:36:56 steve Exp $ */
 #ifndef _CRAY
 #error "ncx_cray.c is a cray specific implementation"
 #endif
@@ -3417,10 +3417,13 @@ ncx_getn_double_double(const void **xpp, size_t nelems, double *tp)
 	if(noff != 0)
 	{
 		/* (*xpp) not word aligned, forced to make a copy */
-		word xbuf[nelems];
+		word *xbuf = (word*)malloc(nelems*sizeof(word));
+		if (xbuf == NULL)
+			return NC_ENOMEM;
 		(void) memcpy(xbuf, *xpp, nelems * X_SIZEOF_DOUBLE);
 		ierr = IEG2CRAY(&Cray2_F64, &nelems, xbuf,
 			&Zero, tp, &UnitStride);
+		(void)free(xbuf);
 	}
 	else
 	{
@@ -3454,18 +3457,27 @@ ncx_getn_double_double(const void **xpp, size_t nelems, double *tp)
 	if(noff != 0)
 	{
 		/* (*xpp) not word aligned, forced to make a copy */
-		word xbuf[nelems];
-		const word *wp = xbuf;
-		const word *const end = &wp[nelems];
+		word *xbuf = (word*)malloc(nelems*sizeof(word));
+		if (xbuf == NULL)
+		{
+			return NC_ENOMEM;
+		}
+		else
+		{
+			const word *wp = xbuf;
+			const word *const end = &wp[nelems];
 
-		(void) memcpy(xbuf, *xpp, nelems * X_SIZEOF_DOUBLE);
+			(void) memcpy(
+				(void*)xbuf, *xpp, nelems * X_SIZEOF_DOUBLE);
 
 #pragma _CRI ivdep
-		for( ; wp < end; wp++, tp++)
-		{
-			cget_double_double(wp, tp);
-		}
+			for( ; wp < end; wp++, tp++)
+			{
+				cget_double_double(wp, tp);
+			}
 
+			(void)free(xbuf);
+		}
 	}
 	else
 	{
@@ -3604,11 +3616,14 @@ ncx_putn_double_double(void **xpp, size_t nelems, const double *tp)
 	if(noff != 0)
 	{
 		/* (*xpp) not word aligned, forced to make a copy */
-		word xbuf[nelems];
+		word *xbuf = (word*)malloc(nelems*sizeof(word));
+		if (xbuf == NULL)
+			return NC_ENOMEM;
 		ierr = CRAY2IEG(&Cray2_F64, &nelems, xbuf,
 			&Zero, tp, &UnitStride);
 		assert(ierr >= 0);
 		(void) memcpy(*xpp, xbuf, nelems * X_SIZEOF_DOUBLE);
+		(void)free(xbuf);
 	}
 	else
 	{
@@ -3643,19 +3658,28 @@ ncx_putn_double_double(void **xpp, size_t nelems, const double *tp)
 	if(noff != 0)
 	{
 		/* (*xpp) not word aligned, forced to make a copy */
-		word xbuf[nelems];
-		word *wp = xbuf;
-		const word *const end = &wp[nelems];
+		word *xbuf = (word*)malloc(nelems*sizeof(word));
+		if (xbuf == NULL)
+		{
+			return NC_ENOMEM;
+		}
+		else
+		{
+			word *wp = xbuf;
+			const word *const end = &wp[nelems];
 
 #pragma _CRI ivdep
-		for( ; wp < end; wp++, tp++)
-		{
-			const int lstatus = cput_double_double(wp, tp);
-			if(lstatus != ENOERR)
-				status = lstatus;
-		}
+			for( ; wp < end; wp++, tp++)
+			{
+				const int lstatus = cput_double_double(wp, tp);
+				if(lstatus != ENOERR)
+					status = lstatus;
+			}
 
-		(void) memcpy(*xpp, xbuf, nelems * X_SIZEOF_DOUBLE);
+			(void) memcpy(
+				*xpp, (void*)xbuf, nelems * X_SIZEOF_DOUBLE);
+			(void)free(xbuf);
+		}
 	}
 	else
 	{
