@@ -2,7 +2,7 @@
  *	Copyright 1996, University Corporation for Atmospheric Research
  *	See netcdf/COPYRIGHT file for copying and redistribution conditions.
  */
-/* $Id: t_ncx.c,v 1.43 1996/11/18 23:22:09 steve Exp $ */
+/* $Id: t_ncx.c,v 1.44 1998/03/06 22:11:18 davis Exp $ */
 
 #include <stdio.h>
 #include <limits.h>
@@ -190,7 +190,7 @@ static double doubles[] = {
  *	Copyright 1993, University Corporation for Atmospheric Research
  *      See netcdf/COPYRIGHT file for copying and redistribution conditions.
  */
-/*	$Id: t_ncx.c,v 1.43 1996/11/18 23:22:09 steve Exp $ */
+/*	$Id: t_ncx.c,v 1.44 1998/03/06 22:11:18 davis Exp $ */
 
 /* putget.c */
 /*
@@ -252,19 +252,6 @@ xdr_NCvbyte(XDR *xdrs, unsigned rem, unsigned count, char *value)
 #define NC_SHRT_BUFSIZ 8192
 #define NC_NSHRTS_PER (NC_SHRT_BUFSIZ/2) /* number of netshorts the buffer holds */
 
-/*
- * Foreign dataset buffer for fast conversions on the cray.  This also
- * to guarantees word alignment for the conversion routines IEG2CRAY() and
- * CRAY2IEG().  Allocate as static because 32K*8bytes is small on a Cray but
- * memory allocations are expensive.  Reuse this  buffer where applicable. 
- * ie. for xdr_longs(), xdr_floats(), xdr_doubles().
- */
-#ifdef CRAY
-#define CrayBuffSize 32768			/* size in 8 byte words   */
-static long IEEEBuff[CrayBuffSize];    		/* word aligned buffer    */
-#endif
-
-
 /*
  * xdr a short leaving adjoining short within the word ok.
  * (minimum unit of io is 4 bytes)
