@@ -2,7 +2,7 @@
  *	Copyright 1996, University Corporation for Atmospheric Research
  *      See netcdf/COPYRIGHT file for copying and redistribution conditions.
  */
-/* $Id: v1hpg.c,v 1.49 1997/12/18 20:03:28 davis Exp $ */
+/* $Id: v1hpg.c,v 1.51 1999/08/24 17:20:44 steve Exp $ */
 
 #include "nc.h"
 #include <stdlib.h>
@@ -115,7 +115,7 @@ fprintf(stderr, "nextread %lu, remaining %lu\n",
 	(unsigned long)((char *)gsp->end - (char *)gsp->pos));
 #endif
 
-	if((char *)gsp->pos + nextread < (char *)gsp->end)
+	if((char *)gsp->pos + nextread <= (char *)gsp->end)
 		return ENOERR;
 	return fault_v1hs(gsp, nextread);
 }
@@ -1202,9 +1202,12 @@ ncx_put_NC(const NC *ncp, void **xpp, off_t offset, size_t extent)
 	if(status != ENOERR)
 		goto release;
 
-	status = ncx_put_size_t(&ps.pos, &ncp->numrecs);
+	{
+	const size_t nrecs = NC_get_numrecs(ncp);
+	status = ncx_put_size_t(&ps.pos, &nrecs);
 	if(status != ENOERR)
 		goto release;
+	}
 
 	assert((char *)ps.pos < (char *)ps.end);
 
@@ -1287,9 +1290,13 @@ nc_get_NC(NC *ncp)
 		}
 	}
 	
-	status = ncx_get_size_t((const void **)(&gs.pos), &ncp->numrecs);
+	{
+	size_t nrecs = 0;
+	status = ncx_get_size_t((const void **)(&gs.pos), &nrecs);
 	if(status != ENOERR)
 		goto unwind_get;
+	NC_set_numrecs(ncp, nrecs);
+	}
 
 	assert((char *)gs.pos < (char *)gs.end);
 
