@@ -2,10 +2,12 @@
  *	Copyright 1996, University Corporation for Atmospheric Research
  *      See netcdf/COPYRIGHT file for copying and redistribution conditions.
  */
-/* $Id: v2i.c,v 1.23 1997/12/11 03:59:17 davis Exp $ */
+/* $Id: v2i.c,v 1.24 2000/10/13 15:48:08 russ Exp $ */
 
 #include "nc.h"
 
+#ifndef NO_NETCDF_2
+
 #if SIZEOF_LONG == SIZEOF_SIZE_T
 /*
  * We don't have to copy the arguments to switch from 'long'
@@ -829,6 +831,7 @@ ncattdel(
 	return 1;
 }
 
+#endif /* NO_NETCDF_2 */
 
 /*
  *  This is how much space is required by the user, as in
@@ -846,18 +849,22 @@ nctypelen(nc_type type)
 	case NC_SHORT :
 		return(int)(sizeof(short));
 	case NC_INT :
-		return((int)sizeof(nclong));
+		return((int)sizeof(int));
 	case NC_FLOAT :
 		return((int)sizeof(float));
 	case NC_DOUBLE : 
 		return((int)sizeof(double));
 	}
+
+#ifndef NO_NETCDF_2
 	/* else */
 	nc_advise("nctypelen", NC_EBADTYPE, "Unknown type %d",
 		(int)type);
+#endif /* NO_NETCDF_2 */
 	return -1;
 }
 
+#ifndef NO_NETCDF_2
 
 int
 ncsetfill(
@@ -941,3 +948,5 @@ ncrecput(
 	}
 	return 0;
 }
+
+#endif /* NO_NETCDF_2 */
