@@ -1,9 +1,11 @@
 /*********************************************************************
  *   Copyright 1996, UCAR/Unidata
  *   See netcdf/COPYRIGHT file for copying and redistribution conditions.
- *   $Id: error.c,v 1.3 1996/07/16 23:06:51 hld Exp $
+ *   $Id: error.c,v 1.5 1998/02/17 20:17:29 steve Exp $
  *********************************************************************/
 
+#include <stddef.h>	/* because gcc 2.7.2.2 doesn't define size_t */
+			/* in <stdio.h> and it cannot hurt */
 #include <stdio.h>
 #include <stdarg.h>
 
@@ -50,3 +52,20 @@ ifFail(const int expr, const int line, const char *file)
     }
     return expr;
 }
+
+/* TODO:
+ * This diagnostic doesn't fit very well with the diagnostic message 
+ * "architecture" of this program.
+ */
+void
+print_n_size_t(size_t nelems, const size_t *array)
+{
+	fprintf(stderr, "[");
+	while(nelems-- > 0)
+	{
+		fprintf(stderr, "%ld", (long)*array++);
+		if(nelems > 0)
+			fprintf(stderr, " ");
+	}
+	fprintf(stderr, "]");
+}
