@@ -1,7 +1,7 @@
 /*********************************************************************
  *   Copyright 1993, University Corporation for Atmospheric Research
  *   See netcdf/README file for copying and redistribution conditions.
- *   $Header: /upc/share/CVS/netcdf-3/ncdump/ncdump.c,v 1.8 1997/09/02 22:14:35 russ Exp $
+ *   $Header: /upc/share/CVS/netcdf-3/ncdump/ncdump.c,v 1.9 2000/08/24 20:40:17 russ Exp $
  *********************************************************************/
 
 #include <stdio.h>
@@ -638,6 +638,7 @@ main(int argc, char *argv[])
     int c;
     int i;
     int max_len = 80;		/* default maximum line length */
+    int nameopt = 0;
 
     opterr = 1;
     progname = argv[0];
@@ -656,6 +657,7 @@ main(int argc, char *argv[])
 				 * file name
 				 */
 	  fspec.name = optarg;
+	  nameopt = 1;
 	  break;
 	case 'b':		/* brief comments in data section */
 	  fspec.brief_data_cmnts = true;
@@ -712,6 +714,7 @@ main(int argc, char *argv[])
     i = 0;
 
     do {		
+        if (!nameopt) fspec.name = (char *)0;
 	if (argc > 0)
 	  do_ncdump(argv[i], &fspec);
     } while (++i < argc);
