@@ -1,7 +1,7 @@
 
 # line 10 "ncgen.y"
 #ifndef lint
-static char SccsId[] = "$Id: ncgen.y,v 1.19 1997/09/02 22:16:34 russ Exp $";
+static char SccsId[] = "$Id: ncgentab.c,v 1.1 1999/01/21 17:01:28 russ Exp $";
 #endif
 #include        <string.h>
 #include	<stdlib.h>
@@ -73,54 +73,18 @@ static void *rec_start;		/* start of space for data */
 # define NETCDF 274
 # define DATA 275
 # define FILLVALUE 276
-
-#ifdef __STDC__
-#include <stdlib.h>
-#include <string.h>
-#else
-#include <malloc.h>
-#include <memory.h>
-#endif
-
-#include <values.h>
-
-#ifdef __cplusplus
-
-#ifndef yyerror
-	void yyerror(const char *);
-#endif
-
-#ifndef yylex
-#ifdef __EXTERN_C__
-	extern "C" { int yylex(void); }
-#else
-	int yylex(void);
-#endif
-#endif
-	int yyparse(void);
-
-#endif
 #define yyclearin yychar = -1
 #define yyerrok yyerrflag = 0
 extern int yychar;
 extern int yyerrflag;
-#ifndef YYSTYPE
-#define YYSTYPE int
-#endif
-YYSTYPE yylval;
-YYSTYPE yyval;
-typedef int yytabelem;
 #ifndef YYMAXDEPTH
 #define YYMAXDEPTH 150
 #endif
-#if YYMAXDEPTH > 0
-int yy_yys[YYMAXDEPTH], *yys = yy_yys;
-YYSTYPE yy_yyv[YYMAXDEPTH], *yyv = yy_yyv;
-#else	/* user does initial allocation */
-int *yys;
-YYSTYPE *yyv;
+#ifndef YYSTYPE
+#define YYSTYPE long
 #endif
-static int yymaxdepth = YYMAXDEPTH;
+YYSTYPE yylval, yyval;
+typedef int yytabelem;
 # define YYERRCODE 256
 
 # line 752 "ncgen.y"
@@ -233,17 +197,17 @@ static const yytabelem yyact[]={
     16,    16 };
 static const yytabelem yypact[]={
 
-  -264,-10000000,   -97,-10000000,  -263,   -50,  -244,-10000000,   -34,   -33,
-   -13,-10000000,-10000000,   -11,  -242,-10000000,-10000000,  -244,    -4,-10000000,
-   -24,-10000000,-10000000,  -268,   -34,   -14,-10000000,-10000000,  -243,-10000000,
--10000000,-10000000,-10000000,-10000000,-10000000,   -15,-10000000,   -25,  -242,-10000000,
--10000000,    -5,-10000000,  -244,  -238,  -102,  -243,   -16,-10000000,     8,
--10000000,-10000000,-10000000,  -253,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,
-  -243,   -17,-10000000,-10000000,  -243,    16,     6,-10000000,-10000000,-10000000,
--10000000,-10000000,-10000000,-10000000,-10000000,-10000000,   -18,-10000000,   -26,-10000000,
--10000000,  -244,  -253,-10000000,-10000000,     7,-10000000,-10000000,-10000000,     5,
--10000000,  -265,-10000000,  -244,-10000000,-10000000,-10000000,-10000000,-10000000,-10000000,
--10000000,-10000000,-10000000,-10000000,-10000000,-10000000 };
+  -264, -1000,   -97, -1000,  -263,   -50,  -244, -1000,   -34,   -33,
+   -13, -1000, -1000,   -11,  -242, -1000, -1000,  -244,    -4, -1000,
+   -24, -1000, -1000,  -268,   -34,   -14, -1000, -1000,  -243, -1000,
+ -1000, -1000, -1000, -1000, -1000,   -15, -1000,   -25,  -242, -1000,
+ -1000,    -5, -1000,  -244,  -238,  -102,  -243,   -16, -1000,     8,
+ -1000, -1000, -1000,  -253, -1000, -1000, -1000, -1000, -1000, -1000,
+  -243,   -17, -1000, -1000,  -243,    16,     6, -1000, -1000, -1000,
+ -1000, -1000, -1000, -1000, -1000, -1000,   -18, -1000,   -26, -1000,
+ -1000,  -244,  -253, -1000, -1000,     7, -1000, -1000, -1000,     5,
+ -1000,  -265, -1000,  -244, -1000, -1000, -1000, -1000, -1000, -1000,
+ -1000, -1000, -1000, -1000, -1000, -1000 };
 static const yytabelem yypgo[]={
 
      0,    94,    92,    91,    90,    89,    88,    87,    60,    53,
@@ -272,7 +236,7 @@ static const yytabelem yyr2[]={
      3,     3,     3,     3,     3 };
 static const yytabelem yychk[]={
 
--10000000,    -1,   274,   123,    -2,    -3,   272,    -4,   273,   -13,
+ -1000,    -1,   274,   123,    -2,    -3,   272,    -4,   273,   -13,
    -17,   -16,   -26,   -29,    58,   -21,   264,    -7,    -8,    -9,
    -10,   -11,   264,    -5,   -12,   -14,   -15,   -16,   -18,   258,
    259,   260,   261,   262,   263,   -17,    59,   -27,    58,   -30,
@@ -296,11 +260,7 @@ static const yytabelem yydef[]={
     34,     0,     0,    60,    65,     0,    38,    40,    48,    62,
     63,     0,    37,     0,    65,    66,    67,    68,    69,    70,
     71,    72,    73,    74,    39,    64 };
-typedef struct
-#ifdef __cplusplus
-	yytoktype
-#endif
-{ char *t_name; int t_val; } yytoktype;
+typedef struct { char *t_name; int t_val; } yytoktype;
 #ifndef YYDEBUG
 #	define YYDEBUG	0	/* don't allow debugging */
 #endif
@@ -335,89 +295,90 @@ yytoktype yytoks[] =
 char * yyreds[] =
 {
 	"-no such reduction-",
-	"ncdesc : NETCDF '{'",
-	"ncdesc : NETCDF '{' dimsection vasection",
-	"ncdesc : NETCDF '{' dimsection vasection datasection '}'",
-	"dimsection : /* empty */",
-	"dimsection : DIMENSIONS dimdecls",
-	"dimdecls : dimdecline ';'",
-	"dimdecls : dimdecls dimdecline ';'",
-	"dimdecline : dimdecl",
-	"dimdecline : dimdecline ',' dimdecl",
-	"dimdecl : dimd '=' INT_CONST",
-	"dimdecl : dimd '=' NC_UNLIMITED_K",
-	"dimd : dim",
-	"dim : IDENT",
-	"vasection : /* empty */",
-	"vasection : VARIABLES vadecls",
-	"vasection : gattdecls",
-	"vadecls : vadecl ';'",
-	"vadecls : vadecls vadecl ';'",
-	"vadecl : vardecl",
-	"vadecl : attdecl",
-	"gattdecls : gattdecl ';'",
-	"gattdecls : gattdecls gattdecl ';'",
-	"gattdecl : attdecl",
-	"vardecl : type varlist",
-	"type : BYTE_K",
-	"type : CHAR_K",
-	"type : SHORT_K",
-	"type : INT_K",
-	"type : FLOAT_K",
-	"type : DOUBLE_K",
-	"varlist : varspec",
-	"varlist : varlist ',' varspec",
-	"varspec : var",
-	"varspec : var dimspec",
-	"var : IDENT",
-	"dimspec : /* empty */",
-	"dimspec : '(' dimlist ')'",
-	"dimlist : vdim",
-	"dimlist : dimlist ',' vdim",
-	"vdim : dim",
-	"attdecl : att",
-	"attdecl : att '=' attvallist",
-	"att : avar ':' attr",
-	"att : ':' attr",
-	"avar : var",
-	"attr : IDENT",
-	"attvallist : aconst",
-	"attvallist : attvallist ',' aconst",
-	"aconst : attconst",
-	"attconst : CHAR_CONST",
-	"attconst : TERMSTRING",
-	"attconst : BYTE_CONST",
-	"attconst : SHORT_CONST",
-	"attconst : INT_CONST",
-	"attconst : FLOAT_CONST",
-	"attconst : DOUBLE_CONST",
-	"datasection : /* empty */",
-	"datasection : DATA datadecls",
-	"datadecls : datadecl ';'",
-	"datadecls : datadecls datadecl ';'",
-	"datadecl : avar",
-	"datadecl : avar '=' constlist",
-	"constlist : dconst",
-	"constlist : constlist ',' dconst",
-	"dconst : /* empty */",
-	"dconst : const",
-	"const : CHAR_CONST",
-	"const : TERMSTRING",
-	"const : BYTE_CONST",
-	"const : SHORT_CONST",
-	"const : INT_CONST",
-	"const : FLOAT_CONST",
-	"const : DOUBLE_CONST",
-	"const : FILLVALUE",
+      "ncdesc : NETCDF '{'",
+      "ncdesc : NETCDF '{' dimsection vasection",
+      "ncdesc : NETCDF '{' dimsection vasection datasection '}'",
+      "dimsection : /* empty */",
+      "dimsection : DIMENSIONS dimdecls",
+      "dimdecls : dimdecline ';'",
+      "dimdecls : dimdecls dimdecline ';'",
+      "dimdecline : dimdecl",
+      "dimdecline : dimdecline ',' dimdecl",
+      "dimdecl : dimd '=' INT_CONST",
+      "dimdecl : dimd '=' NC_UNLIMITED_K",
+      "dimd : dim",
+      "dim : IDENT",
+      "vasection : /* empty */",
+      "vasection : VARIABLES vadecls",
+      "vasection : gattdecls",
+      "vadecls : vadecl ';'",
+      "vadecls : vadecls vadecl ';'",
+      "vadecl : vardecl",
+      "vadecl : attdecl",
+      "gattdecls : gattdecl ';'",
+      "gattdecls : gattdecls gattdecl ';'",
+      "gattdecl : attdecl",
+      "vardecl : type varlist",
+      "type : BYTE_K",
+      "type : CHAR_K",
+      "type : SHORT_K",
+      "type : INT_K",
+      "type : FLOAT_K",
+      "type : DOUBLE_K",
+      "varlist : varspec",
+      "varlist : varlist ',' varspec",
+      "varspec : var",
+      "varspec : var dimspec",
+      "var : IDENT",
+      "dimspec : /* empty */",
+      "dimspec : '(' dimlist ')'",
+      "dimlist : vdim",
+      "dimlist : dimlist ',' vdim",
+      "vdim : dim",
+      "attdecl : att",
+      "attdecl : att '=' attvallist",
+      "att : avar ':' attr",
+      "att : ':' attr",
+      "avar : var",
+      "attr : IDENT",
+      "attvallist : aconst",
+      "attvallist : attvallist ',' aconst",
+      "aconst : attconst",
+      "attconst : CHAR_CONST",
+      "attconst : TERMSTRING",
+      "attconst : BYTE_CONST",
+      "attconst : SHORT_CONST",
+      "attconst : INT_CONST",
+      "attconst : FLOAT_CONST",
+      "attconst : DOUBLE_CONST",
+      "datasection : /* empty */",
+      "datasection : DATA datadecls",
+      "datadecls : datadecl ';'",
+      "datadecls : datadecls datadecl ';'",
+      "datadecl : avar",
+      "datadecl : avar '=' constlist",
+      "constlist : dconst",
+      "constlist : constlist ',' dconst",
+      "dconst : /* empty */",
+      "dconst : const",
+      "const : CHAR_CONST",
+      "const : TERMSTRING",
+      "const : BYTE_CONST",
+      "const : SHORT_CONST",
+      "const : INT_CONST",
+      "const : FLOAT_CONST",
+      "const : DOUBLE_CONST",
+      "const : FILLVALUE",
 };
 #endif /* YYDEBUG */
-# line	1 "/usr/ccs/bin/yaccpar"
 /*
- * Copyright (c) 1993 by Sun Microsystems, Inc.
+ * (c) Copyright 1990, OPEN SOFTWARE FOUNDATION, INC.
+ * ALL RIGHTS RESERVED
  */
-
-#pragma ident	"@(#)yaccpar	6.14	97/01/16 SMI"
-
+/*
+ * OSF/1 Release 1.0
+ */
+/* @(#)yaccpar	1.3  com/cmd/lang/yacc,3.1, 9/7/89 18:46:37 */
 /*
 ** Skeleton parser driver for yacc output
 */
@@ -425,7 +386,12 @@ char * yyreds[] =
 /*
 ** yacc user known macros and defines
 */
-#define YYERROR		goto yyerrlab
+#ifdef YYSPLIT
+#   define YYERROR	return(-2)
+#else
+#   define YYERROR	goto yyerrlab
+#endif
+
 #define YYACCEPT	return(0)
 #define YYABORT		return(1)
 #define YYBACKUP( newtoken, newvalue )\
@@ -441,11 +407,6 @@ char * yyreds[] =
 	goto yynewstate;\
 }
 #define YYRECOVERING()	(!!yyerrflag)
-#define YYNEW(type)	malloc(sizeof(type) * yynewmax)
-#define YYCOPY(to, from, type) \
-	(type *) memcpy(to, (char *) from, yymaxdepth * sizeof (type))
-#define YYENLARGE( from, type) \
-	(type *) realloc((char *) from, yynewmax * sizeof(type))
 #ifndef YYDEBUG
 #	define YYDEBUG	1	/* make debugging available */
 #endif
@@ -458,90 +419,47 @@ int yydebug;			/* set to 1 to get debugging */
 /*
 ** driver internal defines
 */
-#define YYFLAG		(-10000000)
+#define YYFLAG		(-1000)
+
+#ifdef YYSPLIT
+#   define YYSCODE { \
+			extern int (*yyf[])(); \
+			register int yyret; \
+			if (yyf[yytmp]) \
+			    if ((yyret=(*yyf[yytmp])()) == -2) \
+				    goto yyerrlab; \
+				else if (yyret>=0) return(yyret); \
+		   }
+#endif
 
 /*
-** global variables used by the parser
+** local variables used by the parser
+ * these should be static in order to support
+ * multiple parsers in a single executable program. POSIX 1003.2-1993
+ */
+static YYSTYPE yyv[ YYMAXDEPTH ];	/* value stack */
+static int yys[ YYMAXDEPTH ];		/* state stack */
+
+static YYSTYPE *yypv;			/* top of value stack */
+static YYSTYPE *yypvt;			/* top of value stack for $vars */
+static int *yyps;			/* top of state stack */
+
+static int yystate;			/* current state */
+static int yytmp;			/* extra var (lasts between blocks) */
+
+/*
+** global variables used by the parser - renamed as a result of -p
 */
-YYSTYPE *yypv;			/* top of value stack */
-int *yyps;			/* top of state stack */
-
-int yystate;			/* current state */
-int yytmp;			/* extra var (lasts between blocks) */
-
 int yynerrs;			/* number of errors */
 int yyerrflag;			/* error recovery flag */
 int yychar;			/* current input token number */
 
-
-
-#ifdef YYNMBCHARS
-#define YYLEX()		yycvtok(yylex())
-/*
-** yycvtok - return a token if i is a wchar_t value that exceeds 255.
-**	If i<255, i itself is the token.  If i>255 but the neither 
-**	of the 30th or 31st bit is on, i is already a token.
-*/
-#if defined(__STDC__) || defined(__cplusplus)
-int yycvtok(int i)
-#else
-int yycvtok(i) int i;
-#endif
-{
-	int first = 0;
-	int last = YYNMBCHARS - 1;
-	int mid;
-	wchar_t j;
-
-	if(i&0x60000000){/*Must convert to a token. */
-		if( yymbchars[last].character < i ){
-			return i;/*Giving up*/
-		}
-		while ((last>=first)&&(first>=0)) {/*Binary search loop*/
-			mid = (first+last)/2;
-			j = yymbchars[mid].character;
-			if( j==i ){/*Found*/ 
-				return yymbchars[mid].tvalue;
-			}else if( j<i ){
-				first = mid + 1;
-			}else{
-				last = mid -1;
-			}
-		}
-		/*No entry in the table.*/
-		return i;/* Giving up.*/
-	}else{/* i is already a token. */
-		return i;
-	}
-}
-#else/*!YYNMBCHARS*/
-#define YYLEX()		yylex()
-#endif/*!YYNMBCHARS*/
-
 /*
 ** yyparse - return 0 if worked, 1 if syntax error not recovered from
 */
-#if defined(__STDC__) || defined(__cplusplus)
-int yyparse(void)
-#else
-int yyparse()
-#endif
+int
+yyparse()
 {
-	register YYSTYPE *yypvt = 0;	/* top of value stack for $vars */
-
-#if defined(__cplusplus) || defined(lint)
-/*
-	hacks to please C++ and lint - goto's inside
-	switch should never be executed
-*/
-	static int __yaccpar_lint_hack__ = 0;
-	switch (__yaccpar_lint_hack__)
-	{
-		case 1: goto yyerrlab;
-		case 2: goto yynewstate;
-	}
-#endif
-
 	/*
 	** Initialize externals - yyparse may be called more than once
 	*/
@@ -553,23 +471,12 @@ int yyparse()
 	yyerrflag = 0;
 	yychar = -1;
 
-#if YYMAXDEPTH <= 0
-	if (yymaxdepth <= 0)
-	{
-		if ((yymaxdepth = YYEXPAND(0)) <= 0)
-		{
-			yyerror("yacc initialization error");
-			YYABORT;
-		}
-	}
-#endif
-
+	goto yystack;
 	{
 		register YYSTYPE *yy_pv;	/* top of value stack */
 		register int *yy_ps;		/* top of state stack */
 		register int yy_state;		/* current state */
 		register int  yy_n;		/* internal state number info */
-	goto yystack;	/* moved from 6 lines above to here to please C++ */
 
 		/*
 		** get globals into registers.
@@ -625,50 +532,10 @@ int yyparse()
 			}
 		}
 #endif /* YYDEBUG */
-		if ( ++yy_ps >= &yys[ yymaxdepth ] )	/* room on stack? */
+		if ( ++yy_ps >= &yys[ YYMAXDEPTH ] )	/* room on stack? */
 		{
-			/*
-			** reallocate and recover.  Note that pointers
-			** have to be reset, or bad things will happen
-			*/
-			int yyps_index = (yy_ps - yys);
-			int yypv_index = (yy_pv - yyv);
-			int yypvt_index = (yypvt - yyv);
-			int yynewmax;
-#ifdef YYEXPAND
-			yynewmax = YYEXPAND(yymaxdepth);
-#else
-			yynewmax = 2 * yymaxdepth;	/* double table size */
-			if (yymaxdepth == YYMAXDEPTH)	/* first time growth */
-			{
-				char *newyys = (char *)YYNEW(int);
-				char *newyyv = (char *)YYNEW(YYSTYPE);
-				if (newyys != 0 && newyyv != 0)
-				{
-					yys = YYCOPY(newyys, yys, int);
-					yyv = YYCOPY(newyyv, yyv, YYSTYPE);
-				}
-				else
-					yynewmax = 0;	/* failed */
-			}
-			else				/* not first time */
-			{
-				yys = YYENLARGE(yys, int);
-				yyv = YYENLARGE(yyv, YYSTYPE);
-				if (yys == 0 || yyv == 0)
-					yynewmax = 0;	/* failed */
-			}
-#endif
-			if (yynewmax <= yymaxdepth)	/* tables not expanded */
-			{
-				yyerror( "yacc stack overflow" );
-				YYABORT;
-			}
-			yymaxdepth = yynewmax;
-
-			yy_ps = yys + yyps_index;
-			yy_pv = yyv + yypv_index;
-			yypvt = yyv + yypvt_index;
+			yyerror( "yacc stack overflow" );
+			YYABORT;
 		}
 		*yy_ps = yy_state;
 		*++yy_pv = yyval;
@@ -685,7 +552,7 @@ int yyparse()
 		*/
 		yytmp = yychar < 0;
 #endif
-		if ( ( yychar < 0 ) && ( ( yychar = YYLEX() ) < 0 ) )
+		if ( ( yychar < 0 ) && ( ( yychar = yylex() ) < 0 ) )
 			yychar = 0;		/* reached EOF */
 #if YYDEBUG
 		if ( yydebug && yytmp )
@@ -727,7 +594,7 @@ int yyparse()
 #if YYDEBUG
 			yytmp = yychar < 0;
 #endif
-			if ( ( yychar < 0 ) && ( ( yychar = YYLEX() ) < 0 ) )
+			if ( ( yychar < 0 ) && ( ( yychar = yylex() ) < 0 ) )
 				yychar = 0;		/* reached EOF */
 #if YYDEBUG
 			if ( yydebug && yytmp )
@@ -793,9 +660,8 @@ int yyparse()
 				yy_pv = yypv;
 				yy_ps = yyps;
 				yy_state = yystate;
-			skip_init:
 				yynerrs++;
-				/* FALLTHRU */
+			skip_init:
 			case 1:
 			case 2:		/* incompletely recovered error */
 					/* try again... */
@@ -939,31 +805,31 @@ int yyparse()
 	/*
 	** code supplied by user is placed in this switch
 	*/
-	switch( yytmp )
-	{
-		
+
+		switch(yytmp){
+
 case 1:
 # line 97 "ncgen.y"
-{ init_netcdf(); } break;
+{ init_netcdf(); } /*NOTREACHED*/ break;
 case 2:
 # line 100 "ncgen.y"
 {
 		       if (derror_count == 0)
 			 define_netcdf(netcdfname);
-		   } break;
+		   } /*NOTREACHED*/ break;
 case 3:
 # line 106 "ncgen.y"
 {
 		       if (derror_count == 0)
 			 close_netcdf();
-		   } break;
+		   } /*NOTREACHED*/ break;
 case 10:
 # line 121 "ncgen.y"
 { if (int_val <= 0)
 			 derror("dimension length must be positive");
 		     dims[ndims].size = int_val;
 		     ndims++;
-		   } break;
+		   } /*NOTREACHED*/ break;
 case 11:
 # line 127 "ncgen.y"
 {  if (rec_dim != -1)
@@ -971,7 +837,7 @@ case 11:
 		     rec_dim = ndims; /* the unlimited (record) dimension */
 		     dims[ndims].size = NC_UNLIMITED;
 		     ndims++;
-		   } break;
+		   } /*NOTREACHED*/ break;
 case 12:
 # line 135 "ncgen.y"
 { if (yypvt[-0]->is_dim == 1) {
@@ -987,25 +853,25 @@ case 12:
 		     (void) strcpy(dims[ndims].name, yypvt[-0]->name);
 		     /* name for use in generated Fortran and C variables */
 		     dims[ndims].lname = decodify(yypvt[-0]->name);
-		   } break;
+		   } /*NOTREACHED*/ break;
 case 25:
 # line 168 "ncgen.y"
-{ type_code = NC_BYTE; } break;
+{ type_code = NC_BYTE; } /*NOTREACHED*/ break;
 case 26:
 # line 169 "ncgen.y"
-{ type_code = NC_CHAR; } break;
+{ type_code = NC_CHAR; } /*NOTREACHED*/ break;
 case 27:
 # line 170 "ncgen.y"
-{ type_code = NC_SHORT; } break;
+{ type_code = NC_SHORT; } /*NOTREACHED*/ break;
 case 28:
 # line 171 "ncgen.y"
-{ type_code = NC_INT; } break;
+{ type_code = NC_INT; } /*NOTREACHED*/ break;
 case 29:
 # line 172 "ncgen.y"
-{ type_code = NC_FLOAT; } break;
+{ type_code = NC_FLOAT; } /*NOTREACHED*/ break;
 case 30:
 # line 173 "ncgen.y"
-{ type_code = NC_DOUBLE; } break;
+{ type_code = NC_DOUBLE; } /*NOTREACHED*/ break;
 case 33:
 # line 179 "ncgen.y"
 {
@@ -1039,13 +905,13 @@ case 33:
 		     * the variable attribute "_FillValue". */
 		    nc_getfill(type_code, &vars[nvars].fill_value);
 		    vars[nvars].has_data = 0; /* has no data (yet) */
-		   } break;
+		   } /*NOTREACHED*/ break;
 case 34:
 # line 212 "ncgen.y"
 {
 		    vars[nvars].ndims = nvdims;
 		    nvars++;
-		   } break;
+		   } /*NOTREACHED*/ break;
 case 40:
 # line 226 "ncgen.y"
 {
@@ -1066,7 +932,7 @@ case 40:
 				&vars[nvars].dims); /* grow as needed */
 		    vars[nvars].dims[nvdims] = dimnum;
                     nvdims++;
-		   } break;
+		   } /*NOTREACHED*/ break;
 case 41:
 # line 247 "ncgen.y"
 {
@@ -1081,7 +947,7 @@ case 41:
 		       int_valp = (int *) att_space;
 		       float_valp = (float *) att_space;
 		       double_valp = (double *) att_space;
-		   } break;
+		   } /*NOTREACHED*/ break;
 case 42:
 # line 261 "ncgen.y"
 {
@@ -1112,12 +978,12 @@ case 42:
 			   }
 		       }
 		       natts++;
-		   } break;
+		   } /*NOTREACHED*/ break;
 case 44:
 # line 293 "ncgen.y"
 {
 		    varnum = NC_GLOBAL;  /* handle of "global" attribute */
-		   } break;
+		   } /*NOTREACHED*/ break;
 case 45:
 # line 299 "ncgen.y"
 { if (yypvt[-0]->is_var == 1)
@@ -1127,7 +993,7 @@ case 45:
 			     yypvt[-0]->name);
 		      YYABORT;
 		      }
-		   } break;
+		   } /*NOTREACHED*/ break;
 case 46:
 # line 309 "ncgen.y"
 {
@@ -1138,7 +1004,7 @@ case 46:
 		       (void) strcpy(atts[natts].name,yypvt[-0]->name);
 		       /* name for use in generated Fortran and C variables */
 		       atts[natts].lname = decodify(yypvt[-0]->name);
-		   } break;
+		   } /*NOTREACHED*/ break;
 case 49:
 # line 323 "ncgen.y"
 {
@@ -1146,14 +1012,14 @@ case 49:
 		      valtype = atype_code;
 		    if (valtype != atype_code)
 		      derror("values for attribute must be all of same type");
-		   } break;
+		   } /*NOTREACHED*/ break;
 case 50:
 # line 332 "ncgen.y"
 {
 		       atype_code = NC_CHAR;
 		       *char_valp++ = char_val;
 		       valnum++;
-		   } break;
+		   } /*NOTREACHED*/ break;
 case 51:
 # line 338 "ncgen.y"
 {
@@ -1167,42 +1033,42 @@ case 51:
 			   valnum += len;
 			   char_valp += len;
 		       }
-		   } break;
+		   } /*NOTREACHED*/ break;
 case 52:
 # line 351 "ncgen.y"
 {
 		       atype_code = NC_BYTE;
 		       *byte_valp++ = byte_val;
 		       valnum++;
-		   } break;
+		   } /*NOTREACHED*/ break;
 case 53:
 # line 357 "ncgen.y"
 {
 		       atype_code = NC_SHORT;
 		       *short_valp++ = short_val;
 		       valnum++;
-		   } break;
+		   } /*NOTREACHED*/ break;
 case 54:
 # line 363 "ncgen.y"
 {
 		       atype_code = NC_INT;
 		       *int_valp++ = int_val;
 		       valnum++;
-		   } break;
+		   } /*NOTREACHED*/ break;
 case 55:
 # line 369 "ncgen.y"
 {
 		       atype_code = NC_FLOAT;
 		       *float_valp++ = float_val;
 		       valnum++;
-		   } break;
+		   } /*NOTREACHED*/ break;
 case 56:
 # line 375 "ncgen.y"
 {
 		       atype_code = NC_DOUBLE;
 		       *double_valp++ = double_val;
 		       valnum++;
-		   } break;
+		   } /*NOTREACHED*/ break;
 case 61:
 # line 390 "ncgen.y"
 {
@@ -1253,7 +1119,7 @@ case 61:
 			   double_valp = (double *) rec_start;
 			   break;
 		       }
-		 } break;
+		 } /*NOTREACHED*/ break;
 case 62:
 # line 440 "ncgen.y"
 {
@@ -1268,7 +1134,7 @@ case 62:
 		       if (derror_count == 0)
 			   put_variable(rec_start);
 		       free ((char *) rec_start);
-		 } break;
+		 } /*NOTREACHED*/ break;
 case 65:
 # line 458 "ncgen.y"
 {
@@ -1294,7 +1160,7 @@ case 65:
 			   }
 		       }
 		       not_a_string = 1;
-                   } break;
+                   } /*NOTREACHED*/ break;
 case 66:
 # line 483 "ncgen.y"
 {
@@ -1320,7 +1186,7 @@ case 66:
 			       break;
 			   }
 		       }
-		   } break;
+		   } /*NOTREACHED*/ break;
 case 67:
 # line 510 "ncgen.y"
 {
@@ -1346,7 +1212,7 @@ case 67:
 			   break;
 		       }
 		       valnum++;
-		   } break;
+		   } /*NOTREACHED*/ break;
 case 68:
 # line 535 "ncgen.y"
 {
@@ -1402,7 +1268,7 @@ case 68:
 			       break;
 			   }
 		       }
-		   } break;
+		   } /*NOTREACHED*/ break;
 case 69:
 # line 590 "ncgen.y"
 {
@@ -1428,7 +1294,7 @@ case 69:
 			   break;
 		       }
 		       valnum++;
-		   } break;
+		   } /*NOTREACHED*/ break;
 case 70:
 # line 615 "ncgen.y"
 {
@@ -1454,7 +1320,7 @@ case 70:
 			   break;
 		       }
 		       valnum++;
-		   } break;
+		   } /*NOTREACHED*/ break;
 case 71:
 # line 640 "ncgen.y"
 {
@@ -1480,7 +1346,7 @@ case 71:
 			   break;
 		       }
 		       valnum++;
-		   } break;
+		   } /*NOTREACHED*/ break;
 case 72:
 # line 665 "ncgen.y"
 {
@@ -1506,7 +1372,7 @@ case 72:
 			   break;
 		       }
 		       valnum++;
-		   } break;
+		   } /*NOTREACHED*/ break;
 case 73:
 # line 690 "ncgen.y"
 {
@@ -1535,7 +1401,7 @@ case 73:
 			   break;
 		       }
 		       valnum++;
-		   } break;
+		   } /*NOTREACHED*/ break;
 case 74:
 # line 718 "ncgen.y"
 {
@@ -1567,9 +1433,9 @@ case 74:
 			   break;
 		       }
 		       valnum++;
-		   } break;
-# line	531 "/usr/ccs/bin/yaccpar"
-	}
-	goto yystack;		/* reset registers in driver code */
+		   } /*NOTREACHED*/ break;
 }
 
+
+	goto yystack;		/* reset registers in driver code */
+}
